#
# spec file for package ddpt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _bindir /bin
Name:           ddpt
Version:        0.95
Release:        1.1
Summary:        Disk Dump Utility with SCSI Pass-Through Support
License:        BSD-3-Clause
Group:          System/Base
URL:            http://sg.danny.cz/sg/ddpt.html
Source:         http://sg.danny.cz/sg/p/ddpt-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRoot:      %{_tmppath}/build-%{name}-%{version}

%description
dd is a Unix command line utility for copying data. ddpt adds features for
efficiently copying large amounts of data to and from disks. Apart from
accessing disks using traditional Unix read() and write() calls, ddpt can
optionally use SCSI pass-through interfaces to send SCSI commands to perform a
copy. In Linux, the pass-through can be used to send TRIM commands to SSDs. It
is written for Linux with ports to FreeBSD, Solaris, and Windows.

Some features found in ddpt which are not present in the (GNU) dd
implementation:
* sparse writing (i.e. don't write buffer if all zeros)
* write sparing (i.e. don't write buffer if already same as destination)
* resume (after the copy has been interrupted)
* trim on output of copy, self trim (pt interface only)
* send output to a second file (see 'of2=' option)
* access devices directly via pass-through interface, bypassing file system
* accept numeric command line arguments in hexadecimal
* explicit controls over how much data is read into the copy buffer and then
  written to output (separate from the logical block sizes of any device
  involved)

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc AUTHORS COPYING CREDITS ChangeLog NEWS README TODO
/bin/ddpt
/bin/ddptctl
%{_mandir}/man8/ddpt.8%{ext_man}
%{_mandir}/man8/ddptctl.8%{ext_man}

%changelog
* Wed Feb  7 2018 aloisio@gmx.com
- Update to version 0.95
  * add oflag=verify[,bytchk] to write using the SCSI
    WRITE AND VERIFY command
  * add job file that holds options; specified either
    freestanding on command line or after --job=
  * show percent completed
  * add DDPT_DEF_BS environment variable
  * add iflag=ff to source 0xff bytes
  * ddptctl: add --hex and --readonly options
  * add atomic flag for WRITE ATOMIC(16) command on OFILE
  * add warning when oflag=strunc copy interrupted
  * win32: ddpt --wscan fixes
  * point svn:externals to rev 620 of sg3_utils
  * upgrade automake to version 1.14.1
  version 0.94
  * xcopy: change default to send xcopy command to dst
    + add XCOPY_TO_SRC and XCOPY_TO_DST environment
    variables to guide where to send xcopy command
  * odx: add new offloaded copy technique, also known
    as "xcopy v2, lite", that exposes ROD Tokens
    + ddpt supports 4 odx variants: full copy, zero
    output blocks, read to tokens and write from
    tokens. Latter two facilitate network copies
    + add scatter-gather list capability to seek=,
    skip= to read from command line, file or stdin
  * ddptctl: add odx helper utility
    + can issue individual PT, WUT, RRTI, Report All
    Rod Tokens, and Copy Operation Abort commands
    + can decode T10 defined info in Rod Token
  * improve CL handling of short options (e.g. '-vv')
  * point svn:externals to rev 563 of sg3_utils
  * configure: add --disable-libsgutils option so
    build bypasses that library if present
  version 0.93
  * add xcopy support, new flags: xcopy, cat, dc;
    new options: id_usage=, list_id=, prio=
  * add intio=0|1 ; rework signal handling
  * allow tape device in non-pt mode
  * fix fifo read when bs is large
  * add delay=MS,W_MS for bandwidth limiting
  * add oflag=ignoreew,pad,nofm,nopad for tape
  * add iseek= option, synonym for skip=
  * add oseek= option, synonym for seek=
  * add protect=RDP,WRP option
  * add cdbsz=32 option for READ(32) and WRITE(32)
  * add rarc flag for scsi read cdbs
  * add block flag for pt (non blocking by default)
  * fix overflow on OFILE when input fifo
  * ./configure options:
    + change --enable-no-linux-bsg to --disable-linuxbsg
    + add --disable-scsistrings to reduce utility size
    with non-libsgutils build
  * reduce ddpt.c size by adding ddpt_pt.c
  * win32: fixes for cygwin version 1.7.17 headers
    + translate O_EXCL to no sharing
  * point svn:externals to rev 522 of sg3_utils
  * upgrade automake to version 1.13.3
* Fri Feb 18 2011 pascal.bleser@opensuse.org
- initial version (0.92)
